<?php

namespace Litecms\MarketingTool\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\MarketingTool\Models\MarketingTool;

class MarketingToolPolicy
{

    /**
     * Determine if the given user can view the marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function view(UserPolicy $user, MarketingTool $marketing_tool)
    {
        if ($user->canDo('marketing_tool.marketing_tool.view') && $user->isAdmin()) {
            return true;
        }

        return $marketing_tool->user_id == user_id() && $marketing_tool->user_type == user_type();
    }

    /**
     * Determine if the given user can create a marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('marketing_tool.marketing_tool.create');
    }

    /**
     * Determine if the given user can update the given marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function update(UserPolicy $user, MarketingTool $marketing_tool)
    {
        if ($user->canDo('marketing_tool.marketing_tool.edit') && $user->isAdmin()) {
            return true;
        }

        return $marketing_tool->user_id == user_id() && $marketing_tool->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MarketingTool $marketing_tool)
    {
        return $marketing_tool->user_id == user_id() && $marketing_tool->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MarketingTool $marketing_tool)
    {
        if ($user->canDo('marketing_tool.marketing_tool.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given marketing_tool.
     *
     * @param UserPolicy $user
     * @param MarketingTool $marketing_tool
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MarketingTool $marketing_tool)
    {
        if ($user->canDo('marketing_tool.marketing_tool.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
