<?php

namespace Litecms\MarketingTool\Providers;

use Illuminate\Support\ServiceProvider;

class MarketingToolServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'marketing_tool');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'marketing_tool');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.marketing_tool', function ($app) {
            return $this->app->make('Litecms\MarketingTool\MarketingTool');
        });

                // Bind MarketingTool to repository
        $this->app->bind(
            'Litecms\MarketingTool\Interfaces\MarketingToolRepositoryInterface',
            \Litecms\MarketingTool\Repositories\Eloquent\MarketingToolRepository::class
        );

        $this->app->register(\Litecms\MarketingTool\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\MarketingTool\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\MarketingTool\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.marketing_tool'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/marketing_tool.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/marketing_tool')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/marketing_tool')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
